@@ -9,115 +9,95 @@
  */
 function coverPageCatalogue() {
     xml = '<?xml version="1.0" ?> \
-<rtems-docs date="9th February 2023"> \
-  <catalogue>5.3</catalogue> \
+<rtems-docs date="22nd January 2025"> \
+  <catalogue>6.1</catalogue> \
   <doc> \
     <name>user</name> \
     <title>RTEMS User Manual</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>user/index.html</html> \
     <pdf>user.pdf</pdf> \
-    <singlehtml>user.html</singlehtml> \
   </doc> \
   <doc> \
     <name>c-user</name> \
     <title>RTEMS Classic API Guide</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>c-user/index.html</html> \
     <pdf>c-user.pdf</pdf> \
-    <singlehtml>c-user.html</singlehtml> \
   </doc> \
   <doc> \
     <name>bsp-howto</name> \
     <title>RTEMS BSP and Driver Guide</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>bsp-howto/index.html</html> \
     <pdf>bsp-howto.pdf</pdf> \
-    <singlehtml>bsp-howto.html</singlehtml> \
   </doc> \
   <doc> \
     <name>posix-users</name> \
     <title>RTEMS POSIX API Guide</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>posix-users/index.html</html> \
     <pdf>posix-users.pdf</pdf> \
-    <singlehtml>posix-users.html</singlehtml> \
   </doc> \
   <doc> \
     <name>posix-compliance</name> \
     <title>RTEMS POSIX 1003.1 Compliance Guide</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>posix-compliance/index.html</html> \
     <pdf>posix-compliance.pdf</pdf> \
-    <singlehtml>posix-compliance.html</singlehtml> \
   </doc> \
   <doc> \
     <name>eng</name> \
     <title>RTEMS Software Engineering</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>eng/index.html</html> \
     <pdf>eng.pdf</pdf> \
-    <singlehtml>eng.html</singlehtml> \
   </doc> \
   <doc> \
     <name>filesystem</name> \
     <title>RTEMS Filesystem Design Guide</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>filesystem/index.html</html> \
     <pdf>filesystem.pdf</pdf> \
-    <singlehtml>filesystem.html</singlehtml> \
-  </doc> \
-  <doc> \
-    <name>networking</name> \
-    <title>RTEMS Networking User Manual</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
-    <html>networking/index.html</html> \
-    <pdf>networking.pdf</pdf> \
-    <singlehtml>networking.html</singlehtml> \
   </doc> \
   <doc> \
     <name>shell</name> \
     <title>RTEMS Shell Guide</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>shell/index.html</html> \
     <pdf>shell.pdf</pdf> \
-    <singlehtml>shell.html</singlehtml> \
   </doc> \
   <doc> \
     <name>cpu-supplement</name> \
     <title>RTEMS CPU Architecture Supplement</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>cpu-supplement/index.html</html> \
     <pdf>cpu-supplement.pdf</pdf> \
-    <singlehtml>cpu-supplement.html</singlehtml> \
   </doc> \
   <doc> \
     <name>develenv</name> \
     <title>RTEMS Development Environment Guide</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
+    <release>6.1</release> \
+    <version>6.1</version> \
     <html>develenv/index.html</html> \
     <pdf>develenv.pdf</pdf> \
-    <singlehtml>develenv.html</singlehtml> \
   </doc> \
   <doc> \
-    <name>eclipse</name> \
-    <title>RTEMS Eclipse Manual</title> \
-    <release>5.3</release> \
-    <version>5.3</version> \
-    <html>eclipse/index.html</html> \
-    <pdf>eclipse.pdf</pdf> \
-    <singlehtml>eclipse.html</singlehtml> \
+    <name>legacy-networking</name> \
+    <title>RTEMS Legacy Networking User Manual</title> \
+    <release>6.1</release> \
+    <version>6.1</version> \
+    <html>legacy-networking/index.html</html> \
+    <pdf>legacy-networking.pdf</pdf> \
   </doc> \
 </rtems-docs> \
 ';
